@@ -15,6 +15,7 @@ fn document() -> web_sys::Document {
     window().document().expect("No document found!")
 }
 
+#[derive(Clone, Copy)]
 pub struct Document;
 
 impl Document {
@@ -44,8 +45,8 @@ impl Document {
     }
 }
 
+#[derive(Clone)]
 /// An Html Element wrapper
-#[derive(Debug, Clone)]
 pub struct Widget {
     elem: web_sys::Element,
 }
@@ -59,6 +60,11 @@ impl Widget {
         doc.body().unwrap().append_child(&elem).unwrap();
         Self { elem }
     }
+    /// Delete a widget
+    pub fn delete(w: Widget) {
+        w.elem.set_outer_html("");
+        drop(w.elem);
+    }
     /// Create a new widget from an existing Element
     pub fn from_elem(elem: web_sys::Element) -> Self {
         Self { elem }
